@@ -877,12 +877,27 @@ class TranslationSolvers():
         
         for i in range(n_trajectories):
             
+            
+                
             trna_result = np.zeros((len(t)*61),dtype=np.int32)    
             result,ribtimes,frapresult,coltimes,colpointsx,colpointst = self.__generate_vecs_trna(kbind,kindex,t,N_rib,colors)
 
             nribs = np.array([0],dtype=np.int32)
             
-            ssa_translation_lowmem.run_SSA_trna_full(result,trna_result,ribtimes,coltimes,colpointsx,colpointst, kindex,ktrna,kdiffusion,frapresult,t,kbind,kcompl, 0,0,0, seeds[i],nribs,x0,kelong)
+            if i == 0: #detect any int64
+                inputs = [result,trna_result,ribtimes,coltimes,colpointsx,colpointst, kindex,ktrna,kdiffusion,frapresult,t,kbind,kcompl, seeds[i],nribs,x0,kelong]
+                wash_inputs = self.__check_input_memview(inputs)
+            
+            if wash_inputs:
+                #check memview so all given variables are in int32 if integer for C
+                inputs = [result,trna_result,ribtimes,coltimes,colpointsx,colpointst, kindex,ktrna,kdiffusion,frapresult,t,kbind,kcompl, seeds[i],nribs,x0,kelong]
+
+                result,trna_result,ribtimes,coltimes,colpointsx,colpointst, kindex,ktrna,kdiffusion,frapresult,t,kbind,kcompl, seed,nribs,x0,kelong = self.__check_memview(inputs)
+            else:
+
+                seed = seeds[i]
+
+            ssa_translation_lowmem.run_SSA_trna_full(result,trna_result,ribtimes,coltimes,colpointsx,colpointst, kindex,ktrna,kdiffusion,frapresult,t,kbind,kcompl, 0,0,0, seed,nribs,x0,kelong)
                   
             all_results[i, :] = result.T
             all_trna_results[i,:] = trna_result
@@ -1331,21 +1346,25 @@ class TranslationSolvers():
 #        no_ribosomes_per_mrna = np.mean(no_ribosomes)
         
         ssa_obj = SSA_Soln()
-        ssa_obj.no_ribosomes = no_ribosomes
+        if ssa_conditions['record_stats']:
+            ssa_obj.no_ribosomes = no_ribosomes
+            ssa_obj.watched_ribs = watched_ribs
+            ssa_obj.collisions = collisions         
+            
         ssa_obj.n_traj = n_traj
         ssa_obj.k = k
         #ssa_obj.no_rib_per_mrna = no_ribosomes_per_mrna
         #ssa_obj.rib_density = ribosome_density
         #ssa_obj.rib_means = ribosome_means
-        ssa_obj.rib_vec = rib_vec
+
         ssa_obj.intensity_vec = all_results.T[:,startindex:,:]
-        ssa_obj.I = all_results.T[:,startindex:,:]
-        ssa_obj.time_vec_fixed = t
+        #ssa_obj.I = all_results.T[:,startindex:,:]
+        
         ssa_obj.time = t
         ssa_obj.time_rec = t[startindex:]
         ssa_obj.start_time = non_consider_time
-        ssa_obj.watched_ribs = watched_ribs
-        ssa_obj.collisions = collisions
+        ssa_obj.start_index = int(startindex)
+
         
         
         try:
@@ -1354,7 +1373,7 @@ class TranslationSolvers():
             pass
         
         
-        ssa_obj.eval_time = sttime
+        ssa_obj.eval_time = float(sttime)
         
         return ssa_obj        
 
@@ -1492,6 +1511,17 @@ class TranslationSolvers():
         
         
         rib_per_t = np.zeros((n_traj,len(t)))
+        
+        
+        validind = 0
+        riblocs = []
+        for i in range(len(all_rib_loc)):
+            if np.where(np.sum(all_rib_loc[i].T,axis=1)!=0)[0][-1] > validind:
+                validind = np.where(np.sum(all_rib_loc[i].T,axis=1)!=0)[0][-1]
+                
+                
+        all_rib_loc = all_rib_loc[:,:,:validind]
+        
         for i in range(all_rib_loc.shape[0]):
             rib_loc = all_rib_loc[i,:,:]
             rt = np.count_nonzero(rib_loc.T,axis=0)
@@ -1513,13 +1543,12 @@ class TranslationSolvers():
 
         ssa_obj.rib_density = rib_density
         # ssa_obj.rib_means = ribosome_means
-        ssa_obj.rib_vec = rib_vec
         ssa_obj.intensity_vec = all_results.T[:,startindex:,:]
-        ssa_obj.I = all_results.T[:,startindex:,:]
-        ssa_obj.time_vec_fixed = t
+
         ssa_obj.time = t
         ssa_obj.time_rec = t[startindex:]
         ssa_obj.start_time = non_consider_time
+        ssa_obj.start_index = int(startindex)
         ssa_obj.watched_ribs = watched_ribs
         ssa_obj.collisions = collisions
         ssa_obj.ribosome_locations = all_rib_loc
